Acknowledgements
-----------------
`neutcurve` is written by the `Bloom lab  <https://research.fhcrc.org/bloom/en.html>`_.

See https://github.com/jbloomlab/neutcurve/graphs/contributors for the full list of contributors.
